==> eiffelstudio-18.11.10.2592.tar: F_code/C1/st16.c <==
/*
 * Code for class STD_FILES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st16.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STD_FILES}.input */
static EIF_REFERENCE F28_397_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (397);
#define Result RTOSR(397)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdin",5,1953620846);
	F802_4860(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (397);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_397 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(397,F28_397_body,(Current));
}

/* {STD_FILES}.output */
static EIF_REFERENCE F28_398_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (398);
#define Result RTOSR(398)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdout",6,1912016244);
	F802_4861(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (398);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_398 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(398,F28_398_body,(Current));
}

/* {STD_FILES}.error */
static EIF_REFERENCE F28_399_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (399);
#define Result RTOSR(399)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stderr",6,1911360114);
	F802_4862(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (399);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_399 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(399,F28_399_body,(Current));
}

/* {STD_FILES}.default_output */
EIF_REFERENCE F28_400 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {STD_FILES}.standard_default */
EIF_REFERENCE F28_401 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		RTLE;
		return (EIF_REFERENCE) RTOSCF(398,F28_398,(Current));
	}
	RTLE;
	return Result;
}

/* {STD_FILES}.set_output_default */
void F28_423 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(398,F28_398,(Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {STD_FILES}.put_string */
void F28_426 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = F28_401(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1145[Dtype(tr1)-531])(RTCW(tr1), arg1);
	RTLE;
}

/* {STD_FILES}.new_line */
void F28_446 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = F28_401(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R1143[Dtype(tr1)-531])(RTCW(tr1));
	RTLE;
}

void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/st16.c <==
/*
 * Code for class STD_FILES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st16.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STD_FILES}.input */
static EIF_REFERENCE F28_397_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (397);
#define Result RTOSR(397)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdin",5,1953620846);
	F802_4881(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (397);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_397 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(397,F28_397_body,(Current));
}

/* {STD_FILES}.output */
static EIF_REFERENCE F28_398_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (398);
#define Result RTOSR(398)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdout",6,1912016244);
	F802_4882(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (398);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_398 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(398,F28_398_body,(Current));
}

/* {STD_FILES}.error */
static EIF_REFERENCE F28_399_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (399);
#define Result RTOSR(399)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(801, 0x01).id, 801, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stderr",6,1911360114);
	F802_4883(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (399);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F28_399 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(399,F28_399_body,(Current));
}

/* {STD_FILES}.standard_default */
EIF_REFERENCE F28_401 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		Result = RTOSCF(398,F28_398, (Current));
		RTLE;
		return (EIF_REFERENCE) Result;
	}
	RTLE;
	return Result;
}

/* {STD_FILES}.set_output_default */
void F28_423 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(398,F28_398, (Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {STD_FILES}.put_string */
void F28_426 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = F28_401(Current);
	F802_4908(RTCW(tr1), arg1);
	RTLE;
}

/* {STD_FILES}.new_line */
void F28_446 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F802_4916(RTCV(F28_401(Current)));
	RTLE;
}

void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
